from setuptools import setup

setup(
    name='Pycn',
    version='0.0.1',
    packages=['Pycn'],
    url='https://github.com/',
    license='MIT License',
    author='Ruoyu Wang',
    author_email='wangkang@139.com',
    description='王若宇出品的中文python库，用中文写Python~初来乍到，持续更新。'
)
